@@ -6,10 +6,12 @@ use base 'Mail::Karmasphere::Parser::Base';
 
 sub new {
 	my $class = shift;
+#	print STDERR "new: \$class = $class\n";
+#	print STDERR "new: \$class->_streams() = @{[$class->_streams()]}\n";;
 	my $self = ($#_ == 0) ? { %{ (shift) } } : { @_ };
 	unless (exists $self->{Streams}) {
 		$self->{Type} = $class->_type() unless $self->{Type};
-		$self->{Streams} = [ $self->{Type} ];
+		$self->{Streams} = [ $class->_streams() ];
 	}
 	$self = $class->SUPER::new($self);
 	$self->{Value} = 1000 unless exists $self->{Value};
